aboutsummaryrefslogtreecommitdiff
path: root/src/chainparams.h
diff options
context:
space:
mode:
authorshaolinfry <shaolinfry@protonmail.ch>2017-05-05 03:21:34 +0000
committerJorge Timón <jtimon@jtimon.cc>2017-05-30 19:21:51 +0200
commit29c07196d0b8228bacb5746f136b62ffa3586c7b (patch)
treef71ef04738822a8ef28a01a7c39c94dfcd9de820 /src/chainparams.h
parent4314544d46e8e46c3c9da60f1d18297f52f58418 (diff)
downloadbitcoin-29c07196d0b8228bacb5746f136b62ffa3586c7b.tar.xz
Rename -bip9params to -vbparams
Diffstat (limited to 'src/chainparams.h')
-rw-r--r--src/chainparams.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/chainparams.h b/src/chainparams.h
index e5312d1080..a2f136171b 100644
--- a/src/chainparams.h
+++ b/src/chainparams.h
@@ -76,7 +76,7 @@ public:
const std::vector<SeedSpec6>& FixedSeeds() const { return vFixedSeeds; }
const CCheckpointData& Checkpoints() const { return checkpointData; }
const ChainTxData& TxData() const { return chainTxData; }
- void UpdateBIP9Parameters(Consensus::DeploymentPos d, int64_t nStartTime, int64_t nTimeout);
+ void UpdateVersionBitsParameters(Consensus::DeploymentPos d, int64_t nStartTime, int64_t nTimeout);
protected:
CChainParams() {}
@@ -116,8 +116,8 @@ const CChainParams &Params();
void SelectParams(const std::string& chain);
/**
* Allows modifying the BIP9 regtest parameters.
*/
-void UpdateBIP9Parameters(Consensus::DeploymentPos d, int64_t nStartTime, int64_t nTimeout);
+void UpdateVersionBitsParameters(Consensus::DeploymentPos d, int64_t nStartTime, int64_t nTimeout);
#endif // BITCOIN_CHAINPARAMS_H
@@ -116,8 +116,8 @@ const CChainParams &Params();
void SelectParams(const std::string& chain);
/**
- * Allows modifying the BIP9 regtest parameters.
+ * Allows modifying the Version Bits regtest parameters.
*/